@@ -133,7 +133,7 @@ class CallNotify(hildondesktop.StatusMenuItem):
 			index = self.getMissedCallsCount(isSMS) - counter - 1
 			if index >= 5:
 				index = 5
-				if index < 0
+				if index < 0:
 					index = 0
 			if self.msgType != "Both":
 				img = self.imgList[index]
